Utility functions — skchange

Skip to main content
`Ctrl`+`K`

# Utility functions

## Data validation

`check_data`(X, min_length[, min_length_name, ...]) | Check if input data is valid.

## Parameter validation

`check_larger_than`(min_value, value, name[, ...]) | Check if value is non-negative.
`check_smaller_than`(max_value, value, name[, ...]) | Check if value is non-negative.
`check_in_interval`(interval, value, name[, ...]) | Check if value is non-negative.